/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.command;

import java.io.File;
import java.io.IOException;

import org.ow2.petals.cli.api.command.AbstractCommand;
import org.ow2.petals.cli.api.command.exception.CommandException;

/**
 * This command prints the current working directory.
 * @author Sebastien Andre - EBM WebSourcing
 */
public class Pwd extends AbstractCommand {

    public Pwd() {
        super();
        this.setUsage("");
        this.setDescription("Print the working directory");
    }

    /**
     * {@inheritDoc}
     * 
     * <p>
     * Dedicated processing to the command 'pwd': No connection is required to
     * execute it.
     * </p>
     */
    @Override
    public boolean isConnectionRequired() {
        return false;
    }

    @Override
    public void doExecute(final String[] args) throws CommandException {

        try {
            // don't rely on the system property "user.dir"
            final String path = (new File(".")).getCanonicalPath();
            this.getShell().getPrintStream().println(path);
        } catch (final IOException e) {
            throw new CommandException(this, e);
        }
    }

}
