/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.shell;

import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandInvalidException;
import org.ow2.petals.cli.api.command.exception.ConnectionErrorException;
import org.ow2.petals.cli.api.pref.Preferences;
import org.ow2.petals.cli.api.shell.ShellExtension;
import org.ow2.petals.cli.shell.exception.UnknownCommandException;

/**
 * This class is the shell implementation for petals CLI for a command line
 * usage (no script)
 * 
 * @author Sebastien Andre - EBM WebSourcing
 */
public class PetalsCli extends AbstractShell {

    /**
     * Arguments transmitted on the command line that will be executed by Petals
     * CLI.
     */
    final String[] args;

    /**
     * Creates a new PetalsShell
     * 
     * @param args
     * @param isDebugModeEnable
     *            Flag indicating if the debug mode is enable.
     * @param isYesFlagEnable
     *            Flag to enable the automatic confirmation
     * @param preferences
     *            Preferences
     * @param shellExtensions
     *            A list of shell extension, or <code>null</code> if no shell extension is available
     * @param basePrompt
     *            The base prompt
     */
    public PetalsCli(final String[] args, final boolean isDebugModeEnable, final boolean isYesFlagEnable,
            final Preferences preferences, final ShellExtension[] shellExtensions, final String basePrompt) {
        super(System.out, System.err, isDebugModeEnable, isYesFlagEnable, preferences, shellExtensions, basePrompt);
        this.args = args;
    }

    @Override
    public void run() {
        if (this.args != null && this.args.length > 0) {

            try {
                this.evaluate(this.args, true);
                try {
                    // Wait the end of asynchronous commands
                    while (this.isAsynchronousCommandInProgress()) {
                        Thread.sleep(1000);
                    }
                } catch (final InterruptedException e) {
                    // No operation to exit the shell
                }
            } catch (final CommandInvalidException e) {
                this.printCommandSyntaxError(e);
                this.setExitStatus(1);
            } catch (final ConnectionErrorException e) {
                this.printCommandExecutionError(e);
                this.setExitStatus(3);
            } catch (final CommandException e) {
                this.printCommandExecutionError(e);
                this.setExitStatus(2);
            } catch (final UnknownCommandException e) {
                this.printError(e);
                this.setExitStatus(1);
            }
        }
    }

}
