/**
 * Copyright (c) 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.command;

import org.apache.commons.cli.CommandLineParser;
import org.apache.commons.cli.DefaultParser;
import org.apache.commons.cli.MissingArgumentException;
import org.apache.commons.cli.MissingOptionException;
import org.apache.commons.cli.Option;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;
import org.apache.commons.cli.UnrecognizedOptionException;
import org.ow2.petals.cli.api.command.AbstractCommand;
import org.ow2.petals.cli.api.command.exception.CommandBadArgumentNumberException;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandInvalidException;
import org.ow2.petals.cli.api.command.exception.CommandMissingArgumentException;
import org.ow2.petals.cli.api.command.exception.CommandMissingOptionsException;

/**
 * A dummy command for unit tests requiring an argument
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class CommandRequiringAnArgument extends AbstractCommand {

    public static final String NAME = "command-requiring-an-argument";

    public static final String SUCCESSFUL_OUTPUT = NAME + " is ok";

    /**
     * A mandatory option
     */
    public static final String MANDATORY_SHORT_OPTION = "m";

    private static final Option MANDATORY_OPTION = Option.builder(MANDATORY_SHORT_OPTION).hasArg(true).required(true)
            .build();

    public CommandRequiringAnArgument() {
        super(NAME);
    }

	@Override
    public void doExecute(final String[] args) throws CommandException {
        try {
            final CommandLineParser parser = new DefaultParser();
            parser.parse(this.getOptions(), args);
        } catch (final UnrecognizedOptionException e) {
            throw new CommandBadArgumentNumberException(this, e);
        } catch (final MissingArgumentException e) {
            throw new CommandMissingArgumentException(this, e.getOption(), e);
        } catch (final MissingOptionException e) {
            throw new CommandMissingOptionsException(this, e.getMissingOptions(), e);
        } catch (final ParseException e) {
            throw new CommandInvalidException(this, e);
        }
        this.getShell().getPrintStream().println(SUCCESSFUL_OUTPUT);
    }

    @Override
    public Options getOptions() {
        final Options options = new Options();
        options.addOption(MANDATORY_OPTION);
        return options;
    }
}