/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.command;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import org.junit.Test;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.CommandUnparsableArgumentException;
import org.ow2.petals.cli.base.junit.shell.DummyShell;

/**
 * Unit test of {@link Exit}
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ExitTest {

    /**
     * Test that the command usage is defined
     */
    @Test
    public void testUsage_0() throws CommandException {

        final Exit command = new Exit();
        command.setShell(new DummyShell());
        final String usage = command.getUsage();
        assertNotNull("Command usage null", usage);
        assertFalse("Command usage empty", usage.isEmpty());
        assertTrue("'usage' is missing at the begining of the command usage",
                usage.startsWith("usage"));
        assertTrue("The command name is missing in the command usage",
                usage.contains(command.getName()));
    }

    /**
     * Test of the command "exit" against argument management, where:
     * <ul>
     * <li>the argument 'exit code' is not a number.</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: an error occurs about bad number format.
     * </p>
     */
    @Test()
    public void testArgumentsError_0() throws CommandException {
        final String unparsableProperty = "NaN";
        final Exit command = new Exit();
        command.setShell(new DummyShell());
        try {
            command.execute(new String[] { unparsableProperty });
            fail("CommandUnparsableArgumentException is not thrown");
        } catch (final CommandUnparsableArgumentException e) {
            assertTrue("The unparsable value is missing.",
                    e.getMessage().contains(unparsableProperty));
        }
    }

    /**
     * Test of the command "exit", where:
     * <ul>
     * <li>no argument is provided.</li>
     * </ul>
     * </p>
     * <p>
     * Expected results: no error occurs.
     * </p>
     */
    @Test()
    public void testArguments_0() throws CommandException {
        final Exit command = new Exit();
        command.setShell(new DummyShell());

        command.execute(new String[] {});
    }

}
